@@ -73,6 +73,18 @@ pub struct Command {
     /// output will be "minified", i.e. all on one line without whitespace.
     #[clap(long)]
     pub minify_json_abi: bool,
+
+    /// Set the transaction byte price. Defaults to 0.
+    #[clap(long)]
+    pub byte_price: Option<u64>,
+
+    /// Set the transaction gas limit. Defaults to the maximum gas limit.
+    #[clap(long)]
+    pub gas_limit: Option<u64>,
+
+    /// Set the transaction gas price. Defaults to 0.
+    #[clap(long)]
+    pub gas_price: Option<u64>,
 }
 
 pub(crate) async fn exec(command: Command) -> Result<()> {
