@@ -1,8 +1,6 @@
 #![allow(warnings)]
 mod cli;
-mod lock;
 mod ops;
-mod pkg;
 mod utils;
 
 use anyhow::Result;
